@@ -34,7 +34,7 @@ Fsdb - a flat-text database for shell scripting
 
 
 =cut
-our $VERSION = '2.55';
+our $VERSION = '2.56';
 
 =head1 SYNOPSIS
 
@@ -234,34 +234,19 @@ L<http://www.isi.edu/~johnh/SOFTWARE/FSDB/index.html>.
 
 =head1 WHAT'S NEW
 
-=head2 2.55, 2015-01-05
-many spelling fixes and dbcolmovingstats tests are more robust to different numeric precision
+=head2 2.56, 2015-02-03
+fix against Getopt::Long-2.43's stricter error checkign
 
 =over 4
 
-=item ENHANCEMENT
+=item BUG FIX
 
-L<dbfilediff> now can be extra quiet, as I continue to try to track down 
-a numeric difference on FreeBSD AMD boxes.
-
-=item ENHANCEMENT
-
-L<dbcolmovingstats> gave different test output
-(just reflecting rounding error)
-when stddev approaches zero.  We now detect hand handle this case.
-See <https://rt.cpan.org/Public/Bug/Display.html?id=101220>
-and thanks to H. Merijn Brand for the bug report.
+Internal argument parsing uses Getopt::Long, but mixed pass-through and E<lt>E<gt>.
+Bug reported by Petr Pisar at L<https://bugzilla.redhat.com/show_bug.cgi?id=1188538>.
 
 =item BUG FIX
 
-Many, many spelling bugs found by 
-H. Merijn Brand for the bug report.
-
-=item INCOMPATBLE CHANGE
-
-A number of programs had misspelled "separator" 
-in C<--fieldseparator> and C<--columnseparator> options as "seperator".
-These are now correctly spelled.
+Added missing BuildRequires for C<XML::Simple>.
 
 =back
 
@@ -3239,6 +3224,39 @@ Now fixed.
 
 =back
 
+=head2 2.55, 2015-01-05
+many spelling fixes and dbcolmovingstats tests are more robust to different numeric precision
+
+=over 4
+
+=item ENHANCEMENT
+
+L<dbfilediff> now can be extra quiet, as I continue to try to track down 
+a numeric difference on FreeBSD AMD boxes.
+
+=item ENHANCEMENT
+
+L<dbcolmovingstats> gave different test output
+(just reflecting rounding error)
+when stddev approaches zero.  We now detect hand handle this case.
+See <https://rt.cpan.org/Public/Bug/Display.html?id=101220>
+and thanks to H. Merijn Brand for the bug report.
+
+=item BUG FIX
+
+Many, many spelling bugs found by 
+H. Merijn Brand for the bug report.
+
+=item INCOMPATBLE CHANGE
+
+A number of programs had misspelled "separator" 
+in C<--fieldseparator> and C<--columnseparator> options as "seperator".
+These are now correctly spelled.
+
+=back
+
+
+
 =head1 AUTHOR
 
 John Heidemann, C<johnh@isi.edu>
